@@ -1,5 +1,6 @@
 import re
 
+import django
 from django.conf import settings
 from django.forms import widgets
 from django.utils.html import format_html
@@ -18,7 +19,7 @@ class SlugPreviewWidget(widgets.TextInput):
             "admin/js/vendor/jquery/jquery{}.js".format("" if settings.DEBUG else ".min"),
             "admin/js/jquery.init.js",
             "admin/js/urlify.js",
-            "admin/js/prepopulate{}.js".format("" if settings.DEBUG else ".min"),
+            "admin/js/prepopulate{}.js".format("" if settings.DEBUG or django.VERSION >= (3, 2) else ".min"),
             "slug_preview/js/slug_preview.js",
         )
 
